@@ -75,9 +75,8 @@ from os import system
 CURSES_REV=wpath.curses_revision
 
 # Fix strings in wicd-curses
-from wicd.translations import language, _
-for i in language.keys():
-    language[i] = language[i].decode('utf8')
+from wicd.translations import language
+from wicd.translations import _
 
 ########################################
 ##### SUPPORT CLASSES
@@ -828,6 +827,7 @@ class appGUI():
                     self.frame.set_footer(urwid.Pile([self.confCols,self.footer2]))
                     if focus == self.wiredCB:
                         self.diag = WiredSettingsDialog(self.wiredCB.get_body().get_selected_profile(),self.frame)
+                        self.diag.ready_widgets(ui,self.frame)
                         self.frame.set_body(self.diag)
                     else:
                         # wireless list only other option
