@@ -34,7 +34,8 @@ from wicd import misc
 from wicd import wpath
 from wicd.wnettools import GetDefaultGateway, GetWiredInterfaces, \
 GetWirelessInterfaces, IsValidWpaSuppDriver, BaseWirelessInterface, \
-BaseWiredInterface, BaseInterface, wep_pattern, signaldbm_pattern, neediface
+BaseWiredInterface, BaseInterface, GetWpaSupplicantDrivers, wep_pattern, \
+signaldbm_pattern, neediface
 
 try:
     import iwscan
@@ -71,6 +72,7 @@ python-wpactrl (http://projects.otaku42.de/wiki/PythonWpaCtrl)
 python-iwscan (http://projects.otaku42.de/browser/python-iwscan/)"""
 
 RALINK_DRIVER = 'ralink legacy'
+NONE_DRIVER = 'none'
 
 # Got these from /usr/include/linux/wireless.h
 SIOCGIWESSID = 0x8B1B
@@ -288,7 +290,7 @@ class WirelessInterface(Interface, BaseWirelessInterface):
         try:
             results = self.scan_iface.Scan()
         except iwscan.error, e:
-            print "ERROR: %s"
+            print "ERROR: %s" % e
             return []
         return filter(None, [self._parse_ap(cell) for cell in results])
 
